##  Viewing Filtered Fact Sheets in Reports
You can seamlessly transition from inventory to reports without needing to remember or save the applied filters. In the right-side panel, under Show In Report, all relevant reports for the filtered list of fact sheets are displayed. Select any report to see the fact sheets filtered using the same criteria you applied in the inventory.
![Viewing Filtered Fact Sheets in Reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b81f37a441014830ed693ec4fe2f8_LowRes.gif)
Viewing Filtered Fact Sheets in Reports
YesNo
Send
